cat_to_belongings: Convert categories to membership matrix
Description
Function to convert a character vector to a membership matrix (binary matrix).
The columns of the matrix are ordered with the order function.
Usage
cat_to_belongings(categories)catToBelongings(categories)
Arguments
- categories
A vector with the categories of each observation